# -*- coding: utf-8 -*-

__version__ = '1.1.22'
__built__ = '1.1.22 24d5c31b4c8c4ce3a1e6db4bacbd39bfb22c51b7 2021-06-28 15:34 -0600 od'
__author__ = 'Olaf David'
__email__ = 'odavid@colostate.edu'

from .pso import pso
__all__ = ["pso"]

